@@ -15,7 +15,7 @@ use Test2::Compare qw(compare strict_convert);
 use Test2::Require::Module qw(YAML::XS);
 
 use Path::Tiny 0.053;
-use List::SomeUtils qw(uniq);
+use List::Util qw(uniq);
 
 use lib 't/lib';
 use Test2::Require::TestCorpus qw(ScanCode);
@@ -55,7 +55,7 @@ sub licenses ($corpus)
 	return $licenses;
 }
 
-sub expected ( $file, $licenses, $overrides=undef )
+sub expected ( $file, $licenses, $overrides = undef )
 {
 	my ( $stem, $hints, $license_key );
 
@@ -136,7 +136,8 @@ sub parse_skipfile ($file)
 	return $skips;
 }
 
-sub are_licensed_like_scancode ( $testpaths, $skipfile=undef, $overrides=undef )
+sub are_licensed_like_scancode ( $testpaths, $skipfile = undef,
+	$overrides = undef )
 {
 	my ( $ctx, $licenses, $skiplist, $failures );
 
